import * as t from 'drizzle-orm/pg-core';
import { timestamps } from '../util';
import { competitions } from './competitions';
import { rounds } from './rounds';
import { relations } from 'drizzle-orm';

export const bracketTypes = t.pgEnum('bracket_type', ['WINNER', 'LOSER', 'CONSOLATION', 'MAIN']);

export const brackets = t.pgTable('brackets', {
	id: t.uuid('id').primaryKey().defaultRandom(),
	name: t.text('name').notNull(),
	bracketType: bracketTypes('bracket_type').notNull(),
	position: t.integer('position').default(1).notNull(),
	isActive: t.boolean('is_active').default(true).notNull(),
	competition_id: t.uuid('competition_id').notNull(),
	...timestamps
});

export const bracketsRelations = relations(brackets, ({ many, one }) => ({
	competition: one(competitions, {
		fields: [brackets.competition_id],
		references: [competitions.id]
	}),
	rounds: many(rounds)
}));
